@@ -14,26 +14,26 @@
    Copyright 2022, HSPyLib team
 """
 
-import logging as log
-import os
-import sys
-from textwrap import dedent
-
-import urllib3
 from firebase.__classpath__ import _Classpath
 from firebase.core.firebase import Firebase
 from hspylib.core.enums.charset import Charset
-from hspylib.core.enums.exit_status import ExitStatus
 from hspylib.core.tools.commons import syserr
 from hspylib.core.zoned_datetime import now
-from hspylib.modules.cli.application.application import Application
-from hspylib.modules.cli.application.version import Version
+from hspylib.modules.application.exit_status import ExitStatus
+from hspylib.modules.application.version import Version
+from hspylib.modules.cli.tui.tui_application import TUIApplication
+from textwrap import dedent
+
+import logging as log
+import os
+import sys
+import urllib3
 
 # Disable this warning because we are hitting our own database
 urllib3.disable_warnings()
 
 
-class Main(Application):
+class Main(TUIApplication):
     """Firebase Agent - Manage your firebase integration"""
 
     # The welcome message
@@ -51,7 +51,7 @@ class Main(Application):
         self.firebase = Firebase()
 
     def _setup_arguments(self) -> None:
-        # @formatter:off
+        # fmt: off
         self._with_options() \
             .option(
                 'config-dir', 'd', 'config-dir',
@@ -68,51 +68,47 @@ class Main(Application):
                     'glob', 'g', 'glob',
                     'filter path names matching a specified glob pattern.',
                     nargs='?') \
-            .add_argument('db_alias', 'alias to identify the firebase object to fetch') \
-                .add_argument('files', 'list of files to upload (separated by a space)', nargs='*') \
+            .add_parameter('db_alias', 'alias to identify the firebase object to fetch') \
+                .add_parameter('files', 'list of files to upload (separated by a space)', nargs='*') \
             .argument('download', 'download files from your Firebase Realtime Database') \
                 .add_option(
                     'dest-dir', 'd', 'dest-dir',
                     'the destination directory. If omitted, the current directory will be used.',
                     nargs='?', default=self._run_dir) \
-            .add_argument('db_alias', 'alias to identify the firebase object to fetch') \
-        # @formatter:on
+            .add_parameter('db_alias', 'alias to identify the firebase object to fetch')
+        # fmt: on
 
     def _main(self, *params, **kwargs) -> ExitStatus:
         """Run the application with the command line arguments"""
-        log.info(dedent(f'''
+        log.info(
+            dedent(
+                f"""
         {self._app_name} v{self._app_version}
         Settings ==============================
                 STARTED: {now("%Y-%m-%d %H:%M:%S")}
-        '''))
+        """
+            )
+        )
         return self._exec_application()
 
     def _exec_application(self) -> ExitStatus:
         """Execute the specified firebase operation"""
-        op = self.get_arg('operation')
-        if op == 'setup' or not self.firebase.is_configured():
+        op = self.get_arg("operation")
+        if op == "setup" or not self.firebase.is_configured():
             self.firebase.setup()
         # Already handled above
-        if op == 'setup':
-            log.debug('Operation is setup but it was already handled')
-        elif op == 'upload':
-            self.firebase.upload(
-                self.get_arg('db_alias'),
-                self.get_arg('files'),
-                self.get_arg('glob'))
-        elif op == 'download':
-            self.firebase.download(
-                self.get_arg('db_alias'),
-                self.get_arg('dest-dir')
-            )
+        if op == "setup":
+            log.debug("Operation is setup but it was already handled")
+        elif op == "upload":
+            self.firebase.upload(self.get_arg("db_alias"), self.get_arg("files"), self.get_arg("glob"))
+        elif op == "download":
+            self.firebase.download(self.get_arg("db_alias"), self.get_arg("dest-dir"))
         else:
-            syserr(f'### Unhandled operation: {op}')
+            syserr(f"### Unhandled operation: {op}")
             self.usage(ExitStatus.FAILED)
         return ExitStatus.SUCCESS
 
-    def _cleanup(self) -> None:
-        pass
 
 if __name__ == "__main__":
     # Application entry point
-    Main('firebase').INSTANCE.run(sys.argv[1:])
+    Main("firebase").INSTANCE.run(sys.argv[1:])
