@@ -14,14 +14,14 @@
    Copyright 2022, HSPyLib team
 """
 
-import logging as log
-import os
-from typing import List
-
 from firebase.core.agent_config import AgentConfig
 from firebase.core.file_processor import FileProcessor
 from firebase.core.firebase_auth import FirebaseAuth
 from hspylib.core.preconditions import check_argument
+from typing import List
+
+import logging as log
+import os
 
 
 class Firebase:
@@ -37,22 +37,22 @@ class Firebase:
     def setup(self) -> None:
         """Setup a firebase creating or reading an existing firebase configuration file"""
         self.agent_config.prompt()
-        log.debug('New firebase setup: %s', self.agent_config)
+        log.debug("New firebase setup: %s", self.agent_config)
 
     def upload(self, db_alias: str, file_paths: List[str], glob_exp: str) -> bool:
         """Upload files to firebase"""
         self._authenticate()
         url = f"{self.agent_config.url(db_alias)}.json"
         check_argument(len(file_paths) > 0, "Unable to upload file_paths (zero size).")
-        log.debug('Uploading files  alias=%s  files=[%s]', db_alias, ','.join(file_paths))
+        log.debug("Uploading files  alias=%s  files=[%s]", db_alias, ",".join(file_paths))
         return self.processor.upload_files(url, file_paths, glob_exp) > 0
 
     def download(self, db_alias: str, dest_dir: str) -> bool:
         """Download files from firebase specified by it's aliases"""
         self._authenticate()
         url = f"{self.agent_config.url(db_alias)}.json"
-        log.debug('Downloading files  alias=%s  dest_dir=%s', db_alias, dest_dir)
-        return self.processor.download_files(url, dest_dir or os.environ.get('HOME')) > 0
+        log.debug("Downloading files  alias=%s  dest_dir=%s", db_alias, dest_dir)
+        return self.processor.download_files(url, dest_dir or os.environ.get("HOME")) > 0
 
     def is_configured(self) -> bool:
         """Checks whether firebase is properly configured or not"""
