@@ -13,17 +13,17 @@
 
    Copyright 2022, HSPyLib team
 """
-import os
 from abc import ABC
-from typing import Optional
-
-import firebase_admin
 from firebase.exception.exceptions import FirebaseAuthenticationError, FirebaseException, InvalidFirebaseCredentials
 from firebase_admin import auth, credentials
 from firebase_admin.auth import UserNotFoundError, UserRecord
 from firebase_admin.exceptions import FirebaseError
 from hspylib.core.preconditions import check_not_none
 from hspylib.core.tools.commons import sysout
+from typing import Optional
+
+import firebase_admin
+import os
 
 
 class FirebaseAuth(ABC):
@@ -40,7 +40,7 @@ class FirebaseAuth(ABC):
         try:
             creds = credentials.Certificate(certificate_file.format(project_id=project_id))
         except (IOError, ValueError) as err:
-            raise InvalidFirebaseCredentials('Invalid credentials provided') from err
+            raise InvalidFirebaseCredentials("Invalid credentials provided") from err
 
         return creds
 
@@ -52,9 +52,9 @@ class FirebaseAuth(ABC):
         try:
             user = auth.get_user(uuid)
             if user:
-                sysout('Firebase authentication succeeded')
+                sysout("Firebase authentication succeeded")
                 return user
-            raise FirebaseAuthenticationError('Failed to authenticate to Firebase')
+            raise FirebaseAuthenticationError("Failed to authenticate to Firebase")
         except UserNotFoundError as err:
             raise FirebaseAuthenticationError(f"Failed to authenticate to Firebase => {err}") from err
         except (ValueError, FirebaseError) as err:
