@@ -14,22 +14,22 @@
    Copyright 2022, HSPyLib team
 """
 
-import json
-from typing import List
-
 from firebase.entity.file_entry import FileEntry
 from hspylib.core.enums.charset import Charset
 from hspylib.core.zoned_datetime import now
+from typing import List
+
+import json
 
 
 class FirebaseEntry:
-
     def __init__(
         self,
         name: str = None,
         last_update_user: str = None,
         files: List[FileEntry] = None,
-        encoding: Charset = Charset.UTF_8):
+        encoding: Charset = Charset.UTF_8,
+    ):
         self.name = name
         self.last_update_user = last_update_user
         self.files = files if files else []
@@ -44,9 +44,11 @@ class FirebaseEntry:
 
     def payload(self) -> str:
         """Return a firebase request payload for this entry"""
-        return str({
-            'encoding': self.str_encoding,
-            'file_paths': str(self.files),
-            'last_modified': self.last_modified,
-            'last_update_user': self.last_update_user
-        })
+        return str(
+            {
+                "encoding": self.str_encoding,
+                "file_paths": str(self.files),
+                "last_modified": self.last_modified,
+                "last_update_user": self.last_update_user,
+            }
+        )
